:notoc:

=====
Teams
=====

Coiled helps individuals and teams manage their resources, control costs, and collaborate with one another.


Accounts & teams
----------------

`Upon signing up <https://coiled.typeform.com/to/mu6Inr4S>`_, each Coiled user is automatically given their own personal account
(the account name is the same as their username) which they can use to manage software environments,
create cluster configurations, and launch Dask clusters.

Additionally, organizations and other teams can create their own Coiled account and add existing Coiled users to
their team. Team members can be added and removed to an account at https://beta.coiled.io/users. This enables team members
to create software environments, cluster configurations, etc. within a team's account (instead of their personal account)
to easily share resources and collaborate with other team members.

.. figure:: images/team-management.png


Resource limits & tracking costs
--------------------------------

Administrators for each Coiled account can set resource limits for account members like the number of cores a user
can allocate at one time or whether or not to grant access to GPUs (which can be expensive). Additionally,
you can track each cluster's cost over time.

.. figure:: images/cluster-table.png


Sharing
-------

Software environments and cluster configurations which belong to an account are visible and accessible to all
account members. This allows team members to easily control, share, and collaborate on their teams's resources.
